@@ -119,7 +119,7 @@ class MedusaReportGenerator:
 
         report = {
             'timestamp': timestamp,
-            'medusa_version': '6.0.0',
+            'medusa_version': '0.11.0',
             'scan_summary': {
                 'total_issues': len(findings),
                 'files_scanned': scan_results.get('files_scanned', 0),
@@ -180,6 +180,103 @@ class MedusaReportGenerator:
 
         return output_path
 
+    def generate_markdown_report(self, scan_results: Dict[str, Any], output_path: Path = None) -> Path:
+        """Generate Markdown report from scan results"""
+        timestamp = datetime.now().isoformat()
+        findings = scan_results.get('findings', [])
+
+        # Calculate metrics
+        security_score = self.calculate_security_score(findings)
+        risk_level = self.calculate_risk_level(security_score)
+
+        severity_breakdown = {
+            severity: len([f for f in findings if f['severity'] == severity])
+            for severity in ['CRITICAL', 'HIGH', 'MEDIUM', 'LOW', 'UNDEFINED']
+        }
+
+        # Build markdown content
+        md = f"""# MEDUSA Security Scan Report
+
+**Generated:** {datetime.fromisoformat(timestamp).strftime('%B %d, %Y at %H:%M:%S')}
+**MEDUSA Version:** 0.11.0
+
+---
+
+## Executive Summary
+
+| Metric | Value |
+|--------|-------|
+| **Security Score** | **{security_score}/100** |
+| **Risk Level** | **{risk_level}** |
+| **Total Issues** | {len(findings)} |
+| **Files Scanned** | {scan_results.get('files_scanned', 0)} |
+| **Lines Scanned** | {scan_results.get('total_lines_scanned', 0):,} |
+
+---
+
+## Severity Breakdown
+
+| Severity | Count | Percentage |
+|----------|-------|------------|
+"""
+
+        # Add severity rows
+        total_issues = len(findings) if findings else 1  # Avoid division by zero
+        for severity in ['CRITICAL', 'HIGH', 'MEDIUM', 'LOW']:
+            count = severity_breakdown.get(severity, 0)
+            if count > 0:
+                percentage = (count / total_issues) * 100
+                emoji = {'CRITICAL': '🚨', 'HIGH': '🔴', 'MEDIUM': '🟡', 'LOW': '🔵'}.get(severity, '⚪')
+                md += f"| {emoji} **{severity}** | {count} | {percentage:.1f}% |\n"
+
+        md += "\n---\n\n"
+
+        # Add detailed findings
+        if findings:
+            md += "## Detailed Findings\n\n"
+
+            # Sort by severity
+            severity_order = {'CRITICAL': 0, 'HIGH': 1, 'MEDIUM': 2, 'LOW': 3, 'UNDEFINED': 4}
+            sorted_findings = sorted(findings, key=lambda f: severity_order.get(f['severity'], 99))
+
+            for i, finding in enumerate(sorted_findings, 1):
+                severity = finding['severity']
+                emoji = {'CRITICAL': '🚨', 'HIGH': '🔴', 'MEDIUM': '🟡', 'LOW': '🔵', 'UNDEFINED': '⚪'}.get(severity, '⚪')
+
+                md += f"### {i}. {emoji} {severity}: {finding['issue']}\n\n"
+                md += f"**File:** `{finding['file']}:{finding['line']}`  \n"
+                md += f"**Scanner:** {finding['scanner']}  \n"
+                md += f"**Confidence:** {finding.get('confidence', 'N/A')}  \n"
+
+                if finding.get('cwe'):
+                    md += f"**CWE:** [{finding['cwe']}](https://cwe.mitre.org/data/definitions/{finding['cwe']}.html)  \n"
+
+                if finding.get('code'):
+                    md += f"\n**Code:**\n```\n{finding['code']}\n```\n"
+
+                md += "\n---\n\n"
+        else:
+            md += "## Detailed Findings\n\n✨ **No security issues found!** Your code is excellent!\n\n---\n\n"
+
+        # Footer
+        md += """## About MEDUSA
+
+MEDUSA is a multi-language security scanner with 40+ specialized analyzers for all platforms.
+
+**Learn more:** [Pantheon Security](https://pantheonsecurity.io)
+
+---
+
+*Report generated by MEDUSA v0.11.0*
+"""
+
+        # Save markdown report
+        output_path = output_path or self.output_dir / f"medusa-scan-{datetime.now().strftime('%Y%m%d-%H%M%S')}.md"
+        with open(output_path, 'w', encoding='utf-8') as f:
+            f.write(md)
+
+        return output_path
+
     def _build_html_report(self, report: Dict[str, Any]) -> str:
         """Build stunning modern HTML report with glassmorphism and animations"""
         summary = report['scan_summary']
@@ -732,7 +829,7 @@ class MedusaReportGenerator:
         </div>
 
         <div class="footer">
-            <div class="footer-title">MEDUSA v0.9.1.0</div>
+            <div class="footer-title">MEDUSA v0.11.0</div>
             <div>Multi-Language Security Scanner with 40+ Analyzers • Pantheon Security</div>
         </div>
     </div>
